@@ -182,6 +182,7 @@ class AnomalyDetector:
             start_at = f1.current_dates.to_list().index(pd.Timestamp(start_at))
         if not isinstance(stop_at,int):
             stop_at = f1.current_dates.to_list().index(pd.Timestamp(stop_at))
+        stop_at = stop_at + 1
         results = pd.DataFrame(
             {
                 'Date':f1.current_dates.to_list()[start_at:stop_at],
@@ -218,6 +219,66 @@ class AnomalyDetector:
         self.upper = None
         self.mc_results = results.reset_index()
 
+    def MonteCarloDetect_sliding(
+            self,
+            historical_window,
+            step,
+            **kwargs,
+    ):
+        """ detects anomalies by running a series of monte carlo simulations
+        rolling over a span of the series. it is a good idea to 
+        transform the series before running so that it is stationary and not seasonal.
+        in other words, the series distribution should be as close to normal as possible.
+
+        Args:
+            historical_window (int): the number of periods to begin the initial search.
+            step (int): how far to step forward after a scan.
+            **kwargs: passed to the `MonteCarloDetect()` method. `start_at` and `stop_at` passed
+                automatically based on the values passed to the other arguments in this function.
+
+        Returns:
+            None
+
+        >>> from scalecast.AnomalyDetector import AnomalyDetector
+        >>> from scalecast.SeriesTransformer import SeriesTransformer
+        >>> from scalecast.Forecaster import Forecaster
+        >>> import pandas_datareader as pdr
+        >>> df = pdr.get_data_fred('HOUSTNSA',start='1900-01-01',end='2021-06-01')
+        >>> f = Forecaster(y=df['HOUSTNSA'],current_dates=df.index)
+        >>> transformer = SeriesTransformer(f)
+        >>> f = transformer.LogTransform()
+        >>> f = transformer.DiffTransform(1)
+        >>> f = transformer.DiffTransform(12)
+        >>> detector = AnomalyDetector(f)
+        >>> detector.MonteCarloDetect_sliding(60,30)
+        """
+        raw_anom = pd.Series()
+        labeled_anom = pd.Series()
+        y = []
+        n = len(self.f.y)
+        y = self.f.y.to_list()[historical_window:]
+        for end_idx in range(historical_window*2, n+historical_window, step):
+            print(f'scanning from obs {end_idx - historical_window} to obs {end_idx}')
+            self.MonteCarloDetect(end_idx - historical_window, min(end_idx,n-1), **kwargs)
+            raw_anom = (
+                pd.concat([raw_anom,self.raw_anom])
+                .reset_index()
+                .sort_values(['index',0])
+                .drop_duplicates(subset=['index'],keep='last')
+                .set_index('index')[0]
+            )
+            labeled_anom = (
+                pd.concat([labeled_anom,self.labeled_anom])
+                .reset_index()
+                .sort_values(['index',0])
+                .drop_duplicates(subset=['index'],keep='last')
+                .set_index('index')[0]
+            )
+
+        self.raw_anom = raw_anom
+        self.labeled_anom = labeled_anom
+        self.y = y
+
     def WriteAnomtoXvars(self,f=None,future_dates=None,**kwargs):
         """ writes the Xvars from the previously called anomaly detector to Xvars in
         a Forecaster object. each anomaly is its own dummy variable on the date it is 
@@ -226,10 +287,10 @@ class AnomalyDetector:
         Args:
             f (Forecaster): optional. if you pass an object here,
                 that object will receive the Xvars. otherwise,
-                it will pass to a copy of the object passed to
+                it will apply to the copy of the object stored in the
                 the AnomalyDetector object when it was initialized.
                 this Forecaster object is stored in the f attribute.
-            future_dates (int): optionaly. if you pass a future dates
+            future_dates (int): optional. if you pass a future dates
                 length here, it will write that many dates to the
                 Forecaster object and future anomaly variables will be
                 passed as arrays of 0s so that any algorithm you train
@@ -276,8 +337,41 @@ class AnomalyDetector:
         f.ingest_Xvars_df(df,date_col='Date',**kwargs)
         return f
 
-    def _clip_anom(self,f=None,q=10):
-        """ i'm not sure I want to implement this but keeping the code for now
+    def adjust_anom(self,f=None,method='q',q=10):
+        """ changes the values of identified anomalies and returns a Forecaster object.
+
+        Args: 
+            f (Forecaster): optional. if you pass an object here,
+                that object will have its y values altered. otherwise,
+                it will apply to the copy of the object stored in the
+                the AnomalyDetector object when it was initialized.
+                this Forecaster object is stored in the f attribute.
+            method (str): the following methods are supported: "q" and "interpolate".
+                "q" uses q-cutting from pandas and fills values with second-to-last
+                q value in either direction. for example, if q == 10, then high anomaly
+                values will be replaced with the 90th percentile of the rest of the series
+                data. low anomaly values will be replaced with the 10th percentile of the 
+                rest of the series. this is a good method for when your data is stationary.
+                for data with a trend, 'interpolate' is better as it fills in values linearly
+                based on the values before and after consecutive anomaly values. be careful
+                when using "q" with differenced data. when undifferencing,
+                original values will be reverted back to.
+            q (int): default 10. 
+                the q-value to use when method == 'q'.
+                ignored when method != 'q'.
+
+        >>> from scalecast.AnomalyDetector import AnomalyDetector
+        >>> from scalecast.Forecaster import Forecaster
+        >>> import pandas_datareader as pdr
+        >>> df = pdr.get_data_fred('HOUSTNSA',start='1900-01-01',end='2021-06-01')
+        >>> f = Forecaster(y=df['HOUSTNSA'],current_dates=df.index)
+        >>> detector = AnomalyDetector(f)
+        >>> detector.EstimatorDetect(
+        >>>    estimator='arima',
+        >>>    order=(1,1,1),
+        >>>    seasonal_order=(1,1,1),
+        >>> )
+        >>> f = detector.adjust_anom(method='interpolate')
         """
         f = self.f if f is None else f.deepcopy()
         df = pd.DataFrame(
@@ -285,13 +379,50 @@ class AnomalyDetector:
             index = f.current_dates.to_list(),
         )
         df['a'] = self.labeled_anom
-        df['r'] = pd.qcut(df['y'],q=q)
+        
+        if method == 'q':
+            df['r'] = pd.qcut(df['y'],q=q,labels=list(range(q)))
+
+            top = df.loc[df['r'] == (q-1),'y'].min()
+            bottom = df.loc[df['r'] == 0,'y'].max()
+
+            for i, v in df.reset_index().iterrows():
+                if v['a'] == 1:
+                    f.y.values[i] = top if v['y'] > df['y'].mean() else bottom
+        elif method == 'interpolate':
+            df['anom_num'] = 0
+            df['a_1'] = df['a'].shift()
+            df['a_-1'] = df['a'].shift(-1)
+            df = df.fillna(0)
+            df.loc[(df['a_-1'] == 1) & (df['a'] == 0),'anom_num'] = 1
+            df['anom_num'] = df['anom_num'].cumsum()
+            df.loc[
+                ~(
+                    (
+                        (df['a_-1'] == 1) & (df['a'] == 0)
+                    ) | (
+                        df['a'] == 1
+                    ) | (
+                        (df['a_1'] == 1) & (df['a'] == 0)
+                    )
+                ),'anom_num'
+            ] = 0
+
+            for anom in df['anom_num'].unique():
+                if anom == 0:
+                    continue
+                
+                df_tmp = df.loc[df['anom_num'] == anom]
+                idx = df_tmp.iloc[1:-1,:].index.to_list()
+                slope = (df_tmp.iloc[-1,0] - df_tmp.iloc[0,0]) / (df_tmp.shape[0] - 1)
+
+                for i, d in enumerate(idx):
+                    df.loc[d,'y'] = df_tmp.iloc[0,0] + slope*(i+1)
+
+            f.y = df['y'].reset_index(drop=True)
+        else:
+            raise ValueError(f'method arg expected "q" or "interpolate", got {method}')
 
-        top = df.loc[df['r'] == (q-1),'y'].min()
-        bottom = df.loc[df['r'] == 0,'y'].max()
-        for i, v in df.reset_index().iterrows():
-            if v['a'] == 1:
-                f.y.values[i] = top if v['y'] > df['y'].mean() else bottom
         return f
 
     def plot_anom(self,label=True,strftime_fmt='%Y-%m-%d'):
