@@ -57,8 +57,7 @@ class MVForecaster:
         merge_future_dates='longest',
         names=None,
         **kwargs):
-        """ __init__()
-
+        """ 
         Args:
             *fs (Forecaster): Forecaster objects
             not_same_len_action (str): one of 'trim', 'fail'. default 'trim'.
@@ -492,7 +491,7 @@ class MVForecaster:
 
         Args:
             k (int): default 5. the number of folds. must be at least 2.
-            rolling (bool): default False. whether to using a rolling method.
+            rolling (bool): default False. whether to use a rolling method.
             dynamic_tuning (bool): default False.
 
         Returns:
@@ -556,7 +555,9 @@ class MVForecaster:
         grid_evaluated = grid_evaluated_cv.groupby(
             grid_evaluated_cv.columns.to_list()[:-(4 + mvf2.n_series)],
             dropna=False,
-        )['optimized_metric'].mean().reset_index()
+            as_index=False,
+            sort=False,
+        )['optimized_metric'].mean()
 
         # convert back to whatever it was before or it fails when calling the hyperparam vals
         # contributions welcome for a more elegant solution
@@ -611,10 +612,12 @@ class MVForecaster:
                 what to call the model when storing it in the object's history dictionary.
                 if not specified, the model's nickname will be assigned the estimator value ('mlp' will be 'mlp', etc.).
                 duplicated names will be overwritten with the most recently called model.
-            dynamic_testing (bool): default True.
-                whether to dynamically test the forecast (meaning AR terms will be propogated with predicted values).
-                setting this to False means faster performance, but gives a less-good indication of how well the forecast will perform out x amount of periods.
-                when False, test-set metrics effectively become an average of one-step forecasts.
+            dynamic_testing (bool or int):
+                whether to dynamically test the forecast (meaning lags will be propogated with predicted values).
+                if True, evaluates dynamically over the entire out-of-sample slice of data.
+                if int, window evaluates over that many steps (2 for 2-step dynamic forecasting, 12 for 12-step, etc.).
+                setting this to False or 1 means faster performance, 
+                but gives a less-good indication of how well the forecast will perform out x amount of periods.
 
         Returns:
             None
@@ -646,10 +649,12 @@ class MVForecaster:
                 what to call the model when storing it in the object's history dictionary.
                 if not specified, the model's nickname will be assigned the estimator value ('mlp' will be 'mlp', etc.).
                 duplicated names will be overwritten with the most recently called model.
-            dynamic_testing (bool): default True.
-                whether to dynamically test the forecast (meaning AR terms will be propogated with predicted values).
-                setting this to False means faster performance, but gives a less-good indication of how well the forecast will perform out x amount of periods.
-                when False, test-set metrics effectively become an average of one-step forecasts.
+            dynamic_testing (bool or int):
+                whether to dynamically test the forecast (meaning lags will be propogated with predicted values).
+                if True, evaluates dynamically over the entire out-of-sample slice of data.
+                if int, window evaluates over that many steps (2 for 2-step dynamic forecasting, 12 for 12-step, etc.).
+                setting this to False or 1 means faster performance, 
+                but gives a less-good indication of how well the forecast will perform out x amount of periods.
             **kwargs: passed to the _forecast_{estimator}() method.
                 can include lags and normalizer in addition to any given model's specific hyperparameters.
 
@@ -679,6 +684,7 @@ class MVForecaster:
         cross_validate=False,
         dynamic_tuning=False,
         dynamic_testing=True,
+        suffix=None,
         **cvkwargs,
     ):
         """ iterates through a list of models, tunes them using grids in MVGrids.py, and forecasts them.
@@ -692,10 +698,14 @@ class MVForecaster:
                 whether to dynamically tune the forecast (meaning AR terms will be propogated with predicted values).
                 setting this to False means faster performance, but gives a less-good indication of how well the forecast will perform out x amount of periods.
                 when False, metrics effectively become an average of one-step forecasts.
-            dynamic_testing (bool): default True.
-                whether to dynamically test the forecast (meaning AR terms will be propogated with predicted values).
-                setting this to False means faster performance, but gives a less-good indication of how well the forecast will perform out x amount of periods.
-                when False, test-set metrics effectively become an average of one-step forecasts.
+            dynamic_testing (bool or int):
+                whether to dynamically test the forecast (meaning lags will be propogated with predicted values).
+                if True, evaluates dynamically over the entire out-of-sample slice of data.
+                if int, window evaluates over that many steps (2 for 2-step dynamic forecasting, 12 for 12-step, etc.).
+                setting this to False or 1 means faster performance, 
+                but gives a less-good indication of how well the forecast will perform out x amount of periods.
+            suffix (str): optional. a suffix to add to each model as it is evaluate to differentiate them when called
+                later. if unspecified, each model can be called by its estimator name.
             **cvkwargs: passed to the cross_validate() method.
 
         Returns:
@@ -710,12 +720,13 @@ class MVForecaster:
             "MVGrids.py not found in working directory",
         )
         for m in models:
+            call_me = m if suffix is None else m+suffix
             self.set_estimator(m)
             if cross_validate:
                 self.cross_validate(dynamic_tuning=dynamic_tuning,**cvkwargs)
             else:
                 self.tune(dynamic_tuning=dynamic_tuning)
-            self.auto_forecast(dynamic_testing=dynamic_testing)
+            self.auto_forecast(dynamic_testing=dynamic_testing,call_me=call_me)
 
     def set_optimize_on(self, how):
         """ choose how to determine best models by choosing which series should be optimized.
@@ -745,10 +756,12 @@ class MVForecaster:
 
         Args:
             fcster (str): one of _sklearn_estimators_. reads the estimator set to `set_estimator()` method.
-            dynamic_testing (bool):
-                whether to dynamically test the forecast (meaning AR terms will be propogated with predicted values).
-                setting this to False means faster performance, but gives a less-good indication of how well the forecast will perform out x amount of periods.
-                when False, test-set metrics effectively become an average of one-step forecasts.
+            dynamic_testing (bool or int):
+                whether to dynamically test the forecast (meaning lags will be propogated with predicted values).
+                if True, evaluates dynamically over the entire out-of-sample slice of data.
+                if int, window evaluates over that many steps (2 for 2-step dynamic forecasting, 12 for 12-step, etc.).
+                setting this to False or 1 means faster performance, 
+                but gives a less-good indication of how well the forecast will perform out x amount of periods.
             tune (bool): default False.
                 whether the model is being tuned.
                 does not need to be specified by user.
@@ -760,7 +773,7 @@ class MVForecaster:
                 if int, that many lags will be added for all series
                 if list, each element must be ints, and only those lags will be added for each series.
                 if dict, the key must be the user-selected series name, 'series{n}' or 'y{n}' and key is list or int.
-            **kwargs: treated as model hyperparameters and passed to _sklearn_imports_[model]()
+            **kwargs: treated as model hyperparameters and passed to the applicable sklearn estimator.
 
         >>> mvf.set_estimator('gbt')
         >>> mvf.manual_forecast(lags=3) # adds three lags for each series
@@ -841,7 +854,7 @@ class MVForecaster:
 
         def evaluate(trained_models,future,dynamic_testing):
             future = future.reset_index(drop=True)
-            if not dynamic_testing:
+            if dynamic_testing is False:
                 preds = {}
                 future = scale(self.scaler,future)
                 for series, regr in trained_models.items():
@@ -858,12 +871,23 @@ class MVForecaster:
                             series = c.split('_lag')[0]
                             s_num = int(series[1:])
                             idx = i + 1 - ar
-                            if idx > -1:
-                                future.loc[i+1,c] = preds[series][idx]
-                            else:
+                            if idx <= -1:
                                 future.loc[i+1,c] = getattr(self, f'series{s_num}')['y'].to_list()[idx]
+                            elif dynamic_testing is not True and (i+1) % dynamic_testing == 0:
+                                pass
+                            else:
+                                future.loc[i+1,c] = preds[series][idx]
             return preds
 
+        descriptive_assert(
+            isinstance(dynamic_testing,bool) | isinstance(dynamic_testing,int) & (dynamic_testing > -1),
+            ValueError,
+            f"dynamic_testing expected bool or non-negative int type, got {dynamic_testing}",
+        )
+        dynamic_testing = (
+            False if type(dynamic_testing) == int and dynamic_testing == 1 
+            else dynamic_testing
+        ) # 1-step dynamic testing is same as no dynamic testing
         test_length = (self.test_length + (self.validation_length if tune else 0))
         validation_length = self.validation_length
         observed, future = prepare_data(lags)
@@ -1534,7 +1558,7 @@ class MVForecaster:
         """
         return self.history[model]['grid_evaluated'].copy()
 
-    def backtest(self,model,fcst_length='auto',n_iter=10):
+    def backtest(self,model,fcst_length='auto',n_iter=10,jump_back=1):
         """ runs a backtest of a selected evaluated model over a certain 
         amount of iterations to test the average error if that model were 
         implemented over the last so-many actual forecast intervals.
@@ -1553,6 +1577,8 @@ class MVForecaster:
             n_iter (int): default 10. the number of iterations to backtest.
                 models will iteratively train on all data before the fcst_length worth of values.
                 each iteration takes one observation off the end to redo the cast until all of n_iter is exhausted.
+            jump_back (int): default 1. 
+                the number of time steps between two consecutive training sets.
 
         Returns:
             None
@@ -1573,13 +1599,13 @@ class MVForecaster:
         for i in range(n_iter):
             f = self.__deepcopy__()
             if i > 0:
-                f.current_xreg = {k:pd.Series(v.values[:-i]) for k, v in f.current_xreg.items()}
-                f.current_dates = pd.Series(f.current_dates.values[:-i])
+                f.current_xreg = {k:pd.Series(v.values[:-i*jump_back]) for k, v in f.current_xreg.items()}
+                f.current_dates = pd.Series(f.current_dates.values[:-i*jump_back])
                 for k in range(f.n_series):
-                    getattr(f,f'series{k+1}')['y'] = pd.Series(getattr(f,f'series{k+1}')['y'].values[:-i])
-                    getattr(f,f'series{k+1}')['levely'] = getattr(f,f'series{k+1}')['levely'][:-i]
-                f.future_dates = pd.Series(f.future_dates.values[:-i])
-                f.future_xreg = {k:v[:-i] for k, v in f.future_xreg.items()}
+                    getattr(f,f'series{k+1}')['y'] = pd.Series(getattr(f,f'series{k+1}')['y'].values[:-i*jump_back])
+                    getattr(f,f'series{k+1}')['levely'] = getattr(f,f'series{k+1}')['levely'][:-i*jump_back]
+                f.future_dates = pd.Series(f.future_dates.values[:-i*jump_back])
+                f.future_xreg = {k:v[:-i*jump_back] for k, v in f.future_xreg.items()}
 
             f.set_test_length(fcst_length)
             f.set_estimator(f.history[model]['Estimator'])
