@@ -160,6 +160,8 @@ def tune_test_forecast(
     dynamic_testing=True,
     summary_stats=False,
     feature_importance=False,
+    fi_method='pfi',
+    suffix=None,
     **cvkwargs,
 ):
     """ tunes, tests, and forecasts a series of models with a progress bar through tqdm.
@@ -171,18 +173,27 @@ def tune_test_forecast(
         cross_validate (bool): default False
                 whether to tune the model with cross validation. 
                 if False, uses the validation slice of data to tune.
-        dynamic_tuning (bool): default False.
+        dynamic_tuning (bool or int): default False.
             whether to dynamically tune the forecast (meaning AR terms will be propogated with predicted values).
-            setting this to False means faster performance, but gives a less-good indication of how well the forecast will perform out x amount of periods.
-            when False, metrics effectively become an average of one-step forecasts.
-        dynamic_testing (bool): default True.
+            if True, evaluates dynamically over the entire out-of-sample slice of data.
+            if int, window evaluates over that many steps (2 for 2-step dynamic forecasting, 12 for 12-step, etc.).
+            setting this to False or 1 means faster performance, 
+            but gives a less-good indication of how well the forecast will perform out x amount of periods.
+        dynamic_testing (bool or int):
             whether to dynamically test the forecast (meaning AR terms will be propogated with predicted values).
-            setting this to False means faster performance, but gives a less-good indication of how well the forecast will perform out x amount of periods.
-            when False, test-set metrics effectively become an average of one-step forecasts.
+            if True, evaluates dynamically over the entire out-of-sample slice of data.
+            if int, window evaluates over that many steps (2 for 2-step dynamic forecasting, 12 for 12-step, etc.).
+            setting this to False or 1 means faster performance, 
+            but gives a less-good indication of how well the forecast will perform out x amount of periods.
         summary_stats (bool): default False.
             whether to save summary stats for the models that offer those.
         feature_importance (bool): default False.
             whether to save permutation feature importance information for the models that offer those.
+        fi_method (str): one of {'pfi','shap'}, default 'pfi'.
+            the type of feature importance to save for the models that support it.
+            ignored if feature_importance is False.
+        suffix (str): optional. a suffix to add to each model as it is evaluate to differentiate them when called
+            later. if unspecified, each model can be called by its estimator name.
         **cvkwargs: passed to the cross_validate() method.
 
     Returns:
@@ -195,14 +206,15 @@ def tune_test_forecast(
             )
         )
     for m in log_progress(models):
+        call_me = m if suffix is None else m+suffix
         f.set_estimator(m)
         if cross_validate:
             f.cross_validate(dynamic_tuning=dynamic_tuning,**cvkwargs)
         else:
             f.tune(dynamic_tuning=dynamic_tuning)
-        f.auto_forecast(dynamic_testing=dynamic_testing)
+        f.auto_forecast(dynamic_testing=dynamic_testing,call_me=call_me)
 
         if summary_stats:
             f.save_summary_stats()
         if feature_importance:
-            f.save_feature_importance()
\ No newline at end of file
+            f.save_feature_importance(fi_method)
\ No newline at end of file
